Add more functionality to channel groups

Description, blocking, links to/from the app

Test: cts, runtest systemui-notification
Bug: 63927402
Change-Id: Icc8caf319651f9ac2d622fb54110270c89bdff61
diff --git a/proto/src/metrics_constants.proto b/proto/src/metrics_constants.proto
index 3bc5923..a79f244 100644
--- a/proto/src/metrics_constants.proto
+++ b/proto/src/metrics_constants.proto
@@ -1516,7 +1516,7 @@
     // OS: N
     ACTION_ZEN_ALLOW_LIGHTS = 264;
 
     // OPEN: Settings > Notifications > [App] > Topic Notifications
     // CATEGORY: SETTINGS
     // OS: N
     NOTIFICATION_TOPIC_NOTIFICATION = 265;
@@ -4354,6 +4354,11 @@
     // CATEGORY: SETTINGS
     SETTINGS_FEATURE_FLAGS_DASHBOARD = 1156;
 
+    // OPEN: Settings > Notifications > [App] > Topic Notifications
+    // CATEGORY: SETTINGS
+    // OS: P
+    NOTIFICATION_CHANNEL_GROUP = 1157;
+
     // Add new aosp constants above this line.
     // END OF AOSP CONSTANTS
   }
@@ -1516,7 +1516,7 @@
     ACTION_ZEN_ALLOW_LIGHTS = 264;
 
-    // OPEN: Settings > Notifications > [App] > Topic Notifications
+    // OPEN: Settings > Notifications > [App] > Channel Notifications
     // CATEGORY: SETTINGS
     // OS: N